@@ -663,10 +663,6 @@ class AdaptiveComfortMapEntryPoint(DAG):
         self, comfort_model='adaptive', run_period=run_period
     ) -> List[Dict]:
         return [
-            {
-                'from': MapResultInfo()._outputs.viz_config_file,
-                'to': 'metrics/config.json'
-            },
             {
                 'from': MapResultInfo()._outputs.temperature_info,
                 'to': 'results/temperature/results_info.json'
@@ -678,6 +674,18 @@ class AdaptiveComfortMapEntryPoint(DAG):
             {
                 'from': MapResultInfo()._outputs.condition_intensity_info,
                 'to': 'results/condition_intensity/results_info.json'
+            },
+            {
+                'from': MapResultInfo()._outputs.tcp_vis_metadata,
+                'to': 'metrics/TCP/vis_metadata.json'
+            },
+            {
+                'from': MapResultInfo()._outputs.hsp_vis_metadata,
+                'to': 'metrics/HSP/vis_metadata.json'
+            },
+            {
+                'from': MapResultInfo()._outputs.csp_vis_metadata,
+                'to': 'metrics/CSP/vis_metadata.json'
             }
         ]
 
